@@ -1,5 +1,9 @@
 # -*- coding: utf-8 -*-
 
+import gi
+gi.require_version('Peas', '1.0')
+gi.require_version('Gtk', '3.0')
+gi.require_version('Totem', '1.0')
 from gi.repository import GLib, GObject # pylint: disable-msg=E0611
 from gi.repository import Peas, Gtk, Gdk # pylint: disable-msg=E0611
 from gi.repository import Gio, Pango, Totem # pylint: disable-msg=E0611
@@ -494,7 +498,6 @@ class OpenSubtitles (GObject.Object, # pylint: disable-msg=R0902
         # Set up signals
 
         combobox.connect ('changed', self.__on_combobox__changed)
-        self._dialog.connect ('delete-event', self._dialog.hide_on_delete)
         self._dialog.set_transient_for (self._totem.get_main_window ())
         self._dialog.set_position (Gtk.WindowPosition.CENTER_ON_PARENT)
 
