@@ -11,9 +11,9 @@ class SamplePython (GObject.Object, Peas.Activatable):
         GObject.Object.__init__ (self)
 
     def do_activate (self):
-        print "Activating sample Python plugin"
+        print("Activating sample Python plugin")
         self.object.action_fullscreen_toggle ()
 
     def do_deactivate (self):
-        print "Deactivating sample Python plugin"
+        print("Deactivating sample Python plugin")
         self.object.action_fullscreen_toggle ()
