@@ -32,7 +32,7 @@
 #include "totem-main-toolbar.h"
 #include "griloresources.h"
 
-/**
+/*
  * SECTION:totemmaintoolbar
  * @Short_description: An toolbar with oft-used buttons.
  * @Title: TotemMainToolbar
@@ -131,11 +131,9 @@ update_toolbar_state (TotemMainToolbar *bar)
         }
       else
         {
-          const char *format;
           char *label;
 
-          format = g_dngettext (GETTEXT_PACKAGE, "%d selected", "%d selected", priv->n_selected);
-          label = g_strdup_printf (format, priv->n_selected);
+          label = g_strdup_printf (g_dngettext (GETTEXT_PACKAGE, "%d selected", "%d selected", priv->n_selected), priv->n_selected);
           gtk_button_set_label (GTK_BUTTON (priv->selection_menu_button), label);
           g_free (label);
         }
